/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<analitzawrapper.h>)
#  include <analitzawrapper.h>
#endif
#if __has_include(<graph2dmobile.h>)
#  include <graph2dmobile.h>
#endif
#if __has_include(<graph3ditem.h>)
#  include <graph3ditem.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_analitza()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<AnalitzaWrapper>("org.kde.analitza", 1);
    qmlRegisterTypesAndRevisions<ExpressionWrapper>("org.kde.analitza", 1);
    qmlRegisterTypesAndRevisions<Graph2DMobile>("org.kde.analitza", 1);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.analitza", 1);
    qmlRegisterTypesAndRevisions<Graph3DItem>("org.kde.analitza", 1);
    qmlRegisterTypesAndRevisions<OperatorsModelForeign>("org.kde.analitza", 1);
    QMetaType::fromType<OperatorsModelForeign *>().id();
    qmlRegisterTypesAndRevisions<PlotsModelForeign>("org.kde.analitza", 1);
    QMetaType::fromType<PlotsModelForeign *>().id();
    QMetaType::fromType<QQuickFramebufferObject *>().id();
    qmlRegisterTypesAndRevisions<VariablesModelForeign>("org.kde.analitza", 1);
    QMetaType::fromType<VariablesModelForeign *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.analitza", 1, 0);
}

static const QQmlModuleRegistration orgkdeanalitzaRegistration("org.kde.analitza", qml_register_types_org_kde_analitza);
