/****************************************************************************
** Meta object code from reading C++ file 'graph2dmobile.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../analitza-26.07.90/declarative/graph2dmobile.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QSharedPointer>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'graph2dmobile.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13Graph2DMobileE_t {};
} // unnamed namespace

template <> constexpr inline auto Graph2DMobile::qt_create_metaobjectdata<qt_meta_tag_ZN13Graph2DMobileE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Graph2DMobile",
        "QML.Element",
        "Graph2DView",
        "showGridChanged",
        "",
        "modelHasChanged",
        "translate",
        "x",
        "y",
        "scale",
        "s",
        "resetViewport",
        "addFunction",
        "expression",
        "QSharedPointer<Analitza::Variables>",
        "vars",
        "save",
        "QUrl",
        "url",
        "model",
        "QAbstractItemModel*",
        "viewport",
        "QRectF",
        "showGrid",
        "showMinorGrid",
        "keepAspectRatio",
        "currentFunction",
        "ticksShown",
        "minorTicksShown",
        "filters"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showGridChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modelHasChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'translate'
        QtMocHelpers::SlotData<void(qreal, qreal)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 7 }, { QMetaType::QReal, 8 },
        }}),
        // Slot 'scale'
        QtMocHelpers::SlotData<void(qreal, int, int)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QReal, 10 }, { QMetaType::Int, 7 }, { QMetaType::Int, 8 },
        }}),
        // Slot 'resetViewport'
        QtMocHelpers::SlotData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addFunction'
        QtMocHelpers::SlotData<QStringList(const QString &, const QSharedPointer<Analitza::Variables> &)>(12, 4, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'addFunction'
        QtMocHelpers::SlotData<QStringList(const QString &)>(12, 4, QMC::AccessPublic | QMC::MethodCloned, QMetaType::QStringList, {{
            { QMetaType::QString, 13 },
        }}),
        // Slot 'save'
        QtMocHelpers::SlotData<bool(const QUrl &) const>(16, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'model'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'viewport'
        QtMocHelpers::PropertyData<QRectF>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'showGrid'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'showMinorGrid'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'keepAspectRatio'
        QtMocHelpers::PropertyData<bool>(25, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'currentFunction'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'ticksShown'
        QtMocHelpers::PropertyData<bool>(27, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'minorTicksShown'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'filters'
        QtMocHelpers::PropertyData<QStringList>(29, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Graph2DMobile, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject Graph2DMobile::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13Graph2DMobileE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13Graph2DMobileE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13Graph2DMobileE_t>.metaTypes,
    nullptr
} };

void Graph2DMobile::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Graph2DMobile *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showGridChanged(); break;
        case 1: _t->modelHasChanged(); break;
        case 2: _t->translate((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qreal>>(_a[2]))); break;
        case 3: _t->scale((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->resetViewport(); break;
        case 5: { QStringList _r = _t->addFunction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSharedPointer<Analitza::Variables>>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 6: { QStringList _r = _t->addFunction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 7: { bool _r = _t->save((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Graph2DMobile::*)()>(_a, &Graph2DMobile::showGridChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Graph2DMobile::*)()>(_a, &Graph2DMobile::modelHasChanged, 1))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->model(); break;
        case 1: *reinterpret_cast<QRectF*>(_v) = _t->lastViewport(); break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->showGrid(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->showMinorGrid(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->keepAspectRatio(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->currentFunction(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->ticksShownAtAll(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->minorTicksShown(); break;
        case 8: *reinterpret_cast<QStringList*>(_v) = _t->filters(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 1: _t->setViewport(*reinterpret_cast<QRectF*>(_v)); break;
        case 2: _t->setShowGrid(*reinterpret_cast<bool*>(_v)); break;
        case 3: _t->setShowMinorGrid(*reinterpret_cast<bool*>(_v)); break;
        case 4: _t->setKeepAspectRatio(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setCurrentFunction(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setTicksShownAtAll(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setShowMinorTicks(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 1: _t->resetViewport(); break;
        default: break;
        }
    }
}

const QMetaObject *Graph2DMobile::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Graph2DMobile::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13Graph2DMobileE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Analitza::Plotter2D"))
        return static_cast< Analitza::Plotter2D*>(this);
    return QQuickItem::qt_metacast(_clname);
}

int Graph2DMobile::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void Graph2DMobile::showGridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Graph2DMobile::modelHasChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
