/****************************************************************************
** Meta object code from reading C++ file 'plotsview2d.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../analitza-26.07.90/analitzawidgets/plotsview2d.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'plotsview2d.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8Analitza11PlotsView2DE_t {};
} // unnamed namespace

template <> constexpr inline auto Analitza::PlotsView2D::qt_create_metaobjectdata<qt_meta_tag_ZN8Analitza11PlotsView2DE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Analitza::PlotsView2D",
        "status",
        "",
        "msg",
        "viewportChanged",
        "QRectF",
        "showGridChanged",
        "forceRepaint",
        "resetViewport",
        "isFramed",
        "setFramed",
        "fr",
        "isReadOnly",
        "setReadOnly",
        "ro",
        "snapshotToClipboard",
        "setXAxisLabel",
        "label",
        "setYAxisLabel",
        "setGridColor",
        "QColor",
        "color",
        "setTicksShown",
        "QFlags<Qt::Orientation>",
        "o",
        "setAxesShown",
        "zoomIn",
        "zoomOut",
        "modelChanged",
        "changeViewport",
        "vp",
        "showGrid",
        "gridColor",
        "backgroundColor",
        "autoGridStyle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'status'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'viewportChanged'
        QtMocHelpers::SignalData<void(const QRectF &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'showGridChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceRepaint'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetViewport'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'isFramed'
        QtMocHelpers::SlotData<bool() const>(9, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setFramed'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'isReadOnly'
        QtMocHelpers::SlotData<bool() const>(12, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'setReadOnly'
        QtMocHelpers::SlotData<void(bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 14 },
        }}),
        // Slot 'snapshotToClipboard'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setXAxisLabel'
        QtMocHelpers::SlotData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setYAxisLabel'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 },
        }}),
        // Slot 'setGridColor'
        QtMocHelpers::SlotData<void(const QColor &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setTicksShown'
        QtMocHelpers::SlotData<void(QFlags<Qt::Orientation>)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'setAxesShown'
        QtMocHelpers::SlotData<void(QFlags<Qt::Orientation>)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
        // Slot 'zoomIn'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zoomOut'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'modelChanged'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeViewport'
        QtMocHelpers::SlotData<void(const QRectF &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 30 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'showGrid'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'gridColor'
        QtMocHelpers::PropertyData<QColor>(32, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'backgroundColor'
        QtMocHelpers::PropertyData<QColor>(33, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'autoGridStyle'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlotsView2D, qt_meta_tag_ZN8Analitza11PlotsView2DE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Analitza::PlotsView2D::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Analitza11PlotsView2DE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Analitza11PlotsView2DE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8Analitza11PlotsView2DE_t>.metaTypes,
    nullptr
} };

void Analitza::PlotsView2D::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlotsView2D *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->status((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->viewportChanged((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 2: _t->showGridChanged(); break;
        case 3: _t->forceRepaint(); break;
        case 4: _t->resetViewport(); break;
        case 5: { bool _r = _t->isFramed();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->setFramed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: { bool _r = _t->isReadOnly();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setReadOnly((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->snapshotToClipboard(); break;
        case 10: _t->setXAxisLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->setYAxisLabel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->setGridColor((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 13: _t->setTicksShown((*reinterpret_cast<std::add_pointer_t<QFlags<Qt::Orientation>>>(_a[1]))); break;
        case 14: _t->setAxesShown((*reinterpret_cast<std::add_pointer_t<QFlags<Qt::Orientation>>>(_a[1]))); break;
        case 15: _t->zoomIn(); break;
        case 16: _t->zoomOut(); break;
        case 17: _t->modelChanged(); break;
        case 18: _t->changeViewport((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PlotsView2D::*)(const QString & )>(_a, &PlotsView2D::status, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlotsView2D::*)(const QRectF & )>(_a, &PlotsView2D::viewportChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PlotsView2D::*)()>(_a, &PlotsView2D::showGridChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->showGrid(); break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->gridColor(); break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->backgroundColor(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->autoGridStyle(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setShowGrid(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setGridColor(*reinterpret_cast<QColor*>(_v)); break;
        case 2: _t->setBackgroundColor(*reinterpret_cast<QColor*>(_v)); break;
        case 3: _t->setAutoGridStyle(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *Analitza::PlotsView2D::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Analitza::PlotsView2D::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8Analitza11PlotsView2DE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Plotter2D"))
        return static_cast< Plotter2D*>(this);
    return QWidget::qt_metacast(_clname);
}

int Analitza::PlotsView2D::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void Analitza::PlotsView2D::status(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Analitza::PlotsView2D::viewportChanged(const QRectF & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Analitza::PlotsView2D::showGridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
