/*************************************************************************************
 *  Copyright (C) 2020 Aleix Pol Gonzalez <aleixpol@kde.org>                         *
 *                                                                                   *
 *  This program is free software; you can redistribute it and/or                    *
 *  modify it under the terms of the GNU General Public License                      *
 *  as published by the Free Software Foundation; either version 2                   *
 *  of the License, or (at your option) any later version.                           *
 *                                                                                   *
 *  This program is distributed in the hope that it will be useful,                  *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of                   *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                    *
 *  GNU General Public License for more details.                                     *
 *                                                                                   *
 *  You should have received a copy of the GNU General Public License                *
 *  along with this program; if not, write to the Free Software                      *
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA   *
 *************************************************************************************/

#include "realpower.h"

#include <QCoreApplication>

#include "expression.h"
#include "list.h"
#include "value.h"

using namespace Analitza;

const QString RealPower::id = QStringLiteral("realpower");
const ExpressionType RealPower::type = ExpressionType(ExpressionType::Lambda)
                                        .addParameter(ExpressionType::Value)
                                        .addParameter(ExpressionType::Value)
                                        .addParameter(ExpressionType::Value);

Expression RealPower::operator()(const QList<Expression>& args)
{
    const auto x = args.constFirst().toReal().complexValue();
    const auto r = args.constLast().toReal().complexValue();

    double sign = x.real() >= 0 ? 1 : -1;

    Cn reta;
    reta.setValue(sign * std::pow(sign * x, r));

    qDebug() << "retaaaaa" << reta.toString();
    return Expression(reta);
}
