// /qt/qml/org/kde/analitza/Graph3D.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qhash.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>

namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_analitza_Graph3D_qml {
QQmlPrivate::AOTLookupValidation::LookupSignatures expectedLookupSignatures()
{
    using namespace Qt::StringLiterals;
    using namespace QQmlPrivate::AOTLookupValidation;
    return {
        { Lookup{ Type{ u""_s, u"Graph3DItem"_s, u""_s, IsComposite::No, IsIC::No }, u"rotate"_s, u""_s }, MethodSignature{ { u"x"_s, u"y"_s, }, { Type{ u""_s, u"void"_s, u""_s, IsComposite::No, IsIC::No }, Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, }, 3, IsSignal::No } },
        { Lookup{ Type{ u""_s, u"QQuickItem"_s, u""_s, IsComposite::No, IsIC::No }, u"x"_s, u""_s }, PropertySignature{ Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, 4 } },
        { Lookup{ Type{ u""_s, u"QQuickItem"_s, u""_s, IsComposite::No, IsIC::No }, u"y"_s, u""_s }, PropertySignature{ Type{ u""_s, u"double"_s, u""_s, IsComposite::No, IsIC::No }, 5 } },
        { Lookup{ Type{ u""_s, u"QQuickMouseArea"_s, u""_s, IsComposite::No, IsIC::No }, u"parent"_s, u""_s }, PropertySignature{ Type{ u""_s, u"QQuickItem"_s, u""_s, IsComposite::No, IsIC::No }, 0 } },
    };
}

bool validateLookupSignatures(QQmlEngine *engine, QV4::CompiledData::CompilationUnit *cu)
{
    enum ValidationState { Pending, Failed, Succeeded };
    static ValidationState state = Pending;
    if (state == Failed)
        return false;
    if (state == Succeeded)
        return true;
    const auto &expectedSignatures = expectedLookupSignatures();
    for (const auto &[lookup, expectedSignature] : expectedSignatures.asKeyValueRange()) {
        if (!QQmlPrivate::AOTLookupValidation::validateLookupSignature(engine, cu, lookup, expectedSignature)) {
            state = Failed;
            return false;
        }
    }
    state = Succeeded;
    return true;
}

extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x4f,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb8,0xa,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf0,0x54,0xd9,0x99,
0x48,0xc,0x91,0x3c,0x1e,0x78,0x52,0xc5,
0xde,0x5f,0x69,0xc0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x38,0x4,0x0,0x0,
0x5,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0xec,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0xf8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x78,0x1,0x0,0x0,
0x3,0x0,0x0,0x0,0x80,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x98,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x68,0x8,0x0,0x0,
0x98,0x1,0x0,0x0,0xf8,0x1,0x0,0x0,
0x70,0x2,0x0,0x0,0x20,0x3,0x0,0x0,
0xb8,0x3,0x0,0x0,0x8,0x4,0x0,0x0,
0x18,0x4,0x0,0x0,0x28,0x4,0x0,0x0,
0x53,0x1,0x0,0x0,0x60,0x1,0x0,0x0,
0x53,0x1,0x0,0x0,0x70,0x1,0x0,0x0,
0x53,0x1,0x0,0x0,0x80,0x1,0x0,0x0,
0x73,0x0,0x0,0x0,0x90,0x1,0x0,0x0,
0x73,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x53,0x0,0x0,0x0,0x73,0x0,0x0,0x0,
0x90,0x1,0x0,0x0,0xb3,0x0,0x0,0x0,
0x73,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0xc3,0x0,0x0,0x0,0xb4,0x1,0x0,0x0,
0x73,0x0,0x0,0x0,0x90,0x1,0x0,0x0,
0x73,0x0,0x0,0x0,0xa0,0x1,0x0,0x0,
0x53,0x0,0x0,0x0,0xd3,0x1,0x0,0x0,
0xe0,0x1,0x0,0x0,0xa0,0x1,0x0,0x0,
0xd3,0x1,0x0,0x0,0x90,0x1,0x0,0x0,
0xd3,0x1,0x0,0x0,0xa0,0x1,0x0,0x0,
0xc4,0x1,0x0,0x0,0xf3,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0xf5,0x7f,
0xcd,0xcc,0xcc,0xcc,0xcc,0x8c,0x19,0x40,
0x9a,0x99,0x99,0x99,0x99,0xd9,0x4,0x40,
0x44,0x0,0x0,0x0,0x17,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x9,0x0,0x0,0x0,
0xf,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x18,0x7,0x2e,0x2,0x3c,0x3,0x84,0x7,
0x18,0x8,0x2e,0x4,0x3c,0x5,0x84,0x8,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0x8,0x0,0x0,0x0,
0x11,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0xca,0x2e,0x6,0x3c,
0x7,0x30,0xb,0x2e,0x8,0x3c,0x9,0x18,
0x7,0x30,0xc,0x1a,0x7,0x6,0xd4,0x16,
0x6,0x2,0x0,0x0,0x0,0x0,0x0,0x0,
0x74,0x0,0x0,0x0,0x37,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x5,0x0,
0xff,0xff,0xff,0xff,0xd,0x0,0x0,0x0,
0x13,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x22,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x28,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x33,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0xca,0x2e,0xa,0x18,
0x7,0x2e,0xb,0x3c,0xc,0x18,0xc,0x2e,
0xd,0xa2,0xc,0x18,0xa,0x2e,0xe,0x3c,
0xf,0x18,0xc,0x2e,0x10,0xa2,0xc,0x18,
0xb,0xac,0x11,0x7,0x2,0xa,0x2e,0x12,
0x3c,0x13,0x30,0xb,0x2e,0x14,0x3c,0x15,
0x18,0x7,0x30,0xc,0x1a,0x7,0x6,0xd4,
0x16,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x31,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0xe,0x0,0x0,0x0,
0x1a,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x2d,0x0,0x0,0x0,0x1c,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xca,0x2e,0x16,0x18,
0x7,0x2e,0x17,0x3c,0x18,0x3c,0x19,0x18,
0xd,0x6,0x64,0xd,0x50,0x4,0x4,0x1,
0x4c,0x2,0x4,0x2,0x18,0xa,0x2e,0x1a,
0x3c,0x1b,0x18,0xb,0x2e,0x1c,0x3c,0x1d,
0x18,0xc,0xac,0x1e,0x7,0x3,0xa,0x18,
0x6,0xd4,0x16,0x6,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0xc,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x1f,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb8,0x4,0x0,0x0,0xc0,0x4,0x0,0x0,
0xd8,0x4,0x0,0x0,0x0,0x5,0x0,0x0,
0x28,0x5,0x0,0x0,0x48,0x5,0x0,0x0,
0x58,0x5,0x0,0x0,0x70,0x5,0x0,0x0,
0x80,0x5,0x0,0x0,0x98,0x5,0x0,0x0,
0xa8,0x5,0x0,0x0,0xd8,0x5,0x0,0x0,
0xe8,0x5,0x0,0x0,0xf8,0x5,0x0,0x0,
0x20,0x6,0x0,0x0,0x68,0x6,0x0,0x0,
0x80,0x6,0x0,0x0,0xb8,0x6,0x0,0x0,
0xe0,0x6,0x0,0x0,0x28,0x7,0x0,0x0,
0x40,0x7,0x0,0x0,0x78,0x7,0x0,0x0,
0x88,0x7,0x0,0x0,0xa8,0x7,0x0,0x0,
0xc8,0x7,0x0,0x0,0xe8,0x7,0x0,0x0,
0xf0,0x7,0x0,0x0,0xf8,0x7,0x0,0x0,
0x10,0x8,0x0,0x0,0x20,0x8,0x0,0x0,
0x30,0x8,0x0,0x0,0x50,0x8,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x2e,0x0,0x4c,0x0,0x61,0x0,
0x79,0x0,0x6f,0x0,0x75,0x0,0x74,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x61,0x0,0x6e,0x0,
0x61,0x0,0x6c,0x0,0x69,0x0,0x74,0x0,
0x7a,0x0,0x61,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x47,0x0,0x72,0x0,
0x61,0x0,0x70,0x0,0x68,0x0,0x33,0x0,
0x44,0x0,0x56,0x0,0x69,0x0,0x65,0x0,
0x77,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x76,0x0,0x69,0x0,
0x65,0x0,0x77,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x4d,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x41,0x0,
0x72,0x0,0x65,0x0,0x61,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x6d,0x0,0x6f,0x0,
0x75,0x0,0x73,0x0,0x65,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x61,0x0,0x6e,0x0,
0x63,0x0,0x68,0x0,0x6f,0x0,0x72,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x6c,0x0,0x61,0x0,
0x73,0x0,0x74,0x0,0x58,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x6c,0x0,0x61,0x0,
0x73,0x0,0x74,0x0,0x59,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x61,0x0,0x63,0x0,
0x63,0x0,0x65,0x0,0x70,0x0,0x74,0x0,
0x65,0x0,0x64,0x0,0x42,0x0,0x75,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6e,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1e,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x61,0x0,0x63,0x0,0x63,0x0,
0x65,0x0,0x70,0x0,0x74,0x0,0x65,0x0,
0x64,0x0,0x42,0x0,0x75,0x0,0x74,0x0,
0x74,0x0,0x6f,0x0,0x6e,0x0,0x73,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x50,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x18,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x50,0x0,
0x72,0x0,0x65,0x0,0x73,0x0,0x73,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x50,0x0,0x6f,0x0,0x73,0x0,0x69,0x0,
0x74,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x43,0x0,0x68,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x20,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x50,0x0,
0x6f,0x0,0x73,0x0,0x69,0x0,0x74,0x0,
0x69,0x0,0x6f,0x0,0x6e,0x0,0x43,0x0,
0x68,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x57,0x0,0x68,0x0,0x65,0x0,0x65,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x57,0x0,
0x68,0x0,0x65,0x0,0x65,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x4c,0x0,0x65,0x0,
0x66,0x0,0x74,0x0,0x42,0x0,0x75,0x0,
0x74,0x0,0x74,0x0,0x6f,0x0,0x6e,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x52,0x0,0x69,0x0,
0x67,0x0,0x68,0x0,0x74,0x0,0x42,0x0,
0x75,0x0,0x74,0x0,0x74,0x0,0x6f,0x0,
0x6e,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x4d,0x0,0x69,0x0,
0x64,0x0,0x64,0x0,0x6c,0x0,0x65,0x0,
0x42,0x0,0x75,0x0,0x74,0x0,0x74,0x0,
0x6f,0x0,0x6e,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x78,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x79,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x74,0x0,0x61,0x0,0x74,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x73,0x0,0x63,0x0,
0x61,0x0,0x6c,0x0,0x65,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x77,0x0,0x68,0x0,
0x65,0x0,0x65,0x0,0x6c,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x6c,0x0,0x65,0x0,0x44,0x0,
0x65,0x0,0x6c,0x0,0x74,0x0,0x61,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x4c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x4,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x1,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x58,0x0,0x0,0x0,
0xc8,0x0,0x0,0x0,0xe0,0x1,0x0,0x0,
0x4,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x8,0x0,0x10,0x0,
0x9,0x0,0x50,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xa,0x0,0x50,0x0,
0xa,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x1,0x0,0x0,0xa,0x0,0x50,0x0,
0xb,0x0,0x90,0x0,0x14,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x14,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x2,0x0,0x0,0x20,0xd,0x0,0x90,0x0,
0xc,0x0,0x0,0x0,0x2,0x0,0x0,0x20,
0xe,0x0,0x90,0x0,0x13,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1a,0x0,0x90,0x0,
0x1a,0x0,0x20,0x1,0x11,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x13,0x0,0x90,0x0,
0x13,0x0,0xc0,0x1,0xf,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x11,0x0,0x90,0x0,
0x11,0x0,0x40,0x1,0xd,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x90,0x0,
0xf,0x0,0xa0,0x1,0xc,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe,0x0,0x60,0x1,
0xe,0x0,0xd0,0x1,0xb,0x0,0x0,0x0,
0x0,0x0,0x2,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x60,0x1,
0xd,0x0,0xd0,0x1,0x8,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0x90,0x0,
0xc,0x0,0x10,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0xc,0x0,0x90,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x9,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x0,0x10,0x1,
0xc,0x0,0x70,0x1,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("Qt::MouseButtons"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for acceptedButtons at line 15, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
int v2_10_v8_12;
int v2_16;
int v2_18;
int v2_2_v7_4;
int v2_8;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
while (!aotContext->getEnumLookup(1, &s.v2_2_v7_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(4);
#endif
aotContext->initGetEnumLookup(1, []() { static const auto t = QMetaType::fromName("Qt"); return t; }().metaObject(), "MouseButton", "LeftButton");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Qt::MouseButtons"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!aotContext->getEnumLookup(3, &s.v2_8)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
aotContext->initGetEnumLookup(3, []() { static const auto t = QMetaType::fromName("Qt"); return t; }().metaObject(), "MouseButton", "RightButton");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Qt::MouseButtons"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_BitOr
s.v2_10_v8_12 = (s.v2_2_v7_4 | s.v2_8);
{
}
// generate_StoreReg
{
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
while (!aotContext->getEnumLookup(5, &s.v2_16)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(18);
#endif
aotContext->initGetEnumLookup(5, []() { static const auto t = QMetaType::fromName("Qt"); return t; }().metaObject(), "MouseButton", "MiddleButton");
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    const QMetaType returnType = []() { static const auto t = QMetaType::fromName("Qt::MouseButtons"); return t; }();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0]);
 }
return;
}
}
{
}
// generate_BitOr
s.v2_18 = (s.v2_10_v8_12 | s.v2_16);
{
}
{
}
// generate_Ret
if (argv[0]) {
    const QMetaType returnType = QMetaType::fromType<int>();
    returnType.destruct(argv[0]);
    returnType.construct(argv[0], &s.v2_18);
}
return;
}
 },{ 1, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickMouseEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onPressed at line 17, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1, markStack);
    aotContext->mark(v2_7, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_1 = nullptr;
QObject *v2_7 = nullptr;
int v2_3;
int v2_9;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadContextIdLookup(6, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadContextIdLookup(6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
double retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
while (!aotContext->getObjectLookup(7, s.v2_1, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(5);
#endif
aotContext->initGetObjectLookup(7, s.v2_1);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_3 = QJSNumberCoercion::toInteger(std::move(retrieved));
}
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(11, &s.v2_3, QMetaType::fromType<int>());
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
while (!aotContext->loadContextIdLookup(8, &s.v2_7)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
aotContext->initLoadContextIdLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
double retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(11);
#endif
while (!aotContext->getObjectLookup(9, s.v2_7, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(11);
#endif
aotContext->initGetObjectLookup(9, s.v2_7);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_9 = QJSNumberCoercion::toInteger(std::move(retrieved));
}
{
}
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(12, &s.v2_9, QMetaType::fromType<int>());
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 2, 1, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
    argTypes[1] = []() { static const auto t = QMetaType::fromName("QQuickMouseEvent*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onPositionChanged at line 19, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_17, markStack);
    aotContext->mark(v2_1_v7_3, markStack);
    aotContext->mark(v2_34, markStack);
    aotContext->mark(v2_40, markStack);
    aotContext->mark(v2_5, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_17 = nullptr;
QObject *v2_1_v7_3 = nullptr;
QObject *v2_34 = nullptr;
QObject *v2_40 = nullptr;
QObject *v2_5 = nullptr;
double v2_11;
double v2_13_v10_15;
double v2_19_v12_21;
double v2_23;
double v2_25_v11_27;
double v2_7_v12_9;
int v2_36;
int v2_42;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadContextIdLookup(10, &s.v2_1_v7_3)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadContextIdLookup(10);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(7);
#endif
while (!aotContext->loadContextIdLookup(11, &s.v2_5)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(7);
#endif
aotContext->initLoadContextIdLookup(11);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
while (!aotContext->getObjectLookup(12, s.v2_5, &s.v2_7_v12_9)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(9);
#endif
aotContext->initGetObjectLookup(12, s.v2_5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(13, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(13);
#endif
aotContext->initLoadScopeObjectPropertyLookup(13);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_11 = double(std::move(retrieved));
}
{
}
// generate_Sub
s.v2_13_v10_15 = (s.v2_7_v12_9 - s.v2_11);
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
while (!aotContext->loadContextIdLookup(14, &s.v2_17)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(19);
#endif
aotContext->initLoadContextIdLookup(14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(21);
#endif
while (!aotContext->getObjectLookup(15, s.v2_17, &s.v2_19_v12_21)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(21);
#endif
aotContext->initGetObjectLookup(15, s.v2_17);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
{
int retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(25);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(16, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(25);
#endif
aotContext->initLoadScopeObjectPropertyLookup(16);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_23 = double(std::move(retrieved));
}
{
}
// generate_Sub
s.v2_25_v11_27 = (s.v2_19_v12_21 - s.v2_23);
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const auto doCall = [&]() {
    void *args[] = {nullptr, &s.v2_13_v10_15, &s.v2_25_v11_27};
    return aotContext->callObjectPropertyLookup(17, s.v2_1_v7_3, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(17, s.v2_1_v7_3, 3);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(34);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(34);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(36);
#endif
while (!aotContext->loadContextIdLookup(18, &s.v2_34)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(36);
#endif
aotContext->initLoadContextIdLookup(18);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
double retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
while (!aotContext->getObjectLookup(19, s.v2_34, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
aotContext->initGetObjectLookup(19, s.v2_34);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_36 = QJSNumberCoercion::toInteger(std::move(retrieved));
}
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(11, &s.v2_36, QMetaType::fromType<int>());
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
while (!aotContext->loadContextIdLookup(20, &s.v2_40)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(42);
#endif
aotContext->initLoadContextIdLookup(20);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
double retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(44);
#endif
while (!aotContext->getObjectLookup(21, s.v2_40, &retrieved)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(44);
#endif
aotContext->initGetObjectLookup(21, s.v2_40);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_42 = QJSNumberCoercion::toInteger(std::move(retrieved));
}
{
}
{
}
// generate_StoreNameSloppy
aotContext->storeNameSloppy(12, &s.v2_42, QMetaType::fromType<int>());
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickItem*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fill at line 12, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(31, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(31);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_0;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
